# so3_parameters_t Struct Reference

`#include <so3_types.h>`

## Data Fields
int | verbosity
int | reality
int | L0
int | L
int | N
so3_sampling_t | sampling_scheme
so3_n_order_t | n_order
so3_storage_t | storage
so3_n_mode_t | n_mode
ssht_dl_method_t | dl_method
int | steerable

## Detailed Description

A struct with all parameters that are common to several functions of the API. In general only one struct needs to be created and a const pointer to it is passed around.

Attention:
  Make sure to use an initializer upon declaration, even if it is left empty. This ensures that all fields are initialized to zero (even if in non-static storage). This way, your code will remain backwards compatible if more fields are added to this struct in the future:

       {.c}
         so3_parameters_t parameters = {};

Definition at line 118 of file so3_types.h.

## Field Documentation

ssht_dl_method_t so3_parameters_t::dl_method

Recursion method to use for computing Wigner functions.

Definition at line 183 of file so3_types.h.

Referenced by so3_core_forward_direct(), so3_core_forward_direct_real(), so3_core_forward_via_ssht(), so3_core_forward_via_ssht_real(), so3_core_inverse_direct(), so3_core_inverse_direct_real(), so3_core_inverse_via_ssht(), and so3_core_inverse_via_ssht_real().

int so3_parameters_t::L

Upper harmonic band-limit. Only flmn with l < L will be stored and considered.

Definition at line 144 of file so3_types.h.

Referenced by main(), so3_core_forward_direct(), so3_core_forward_direct_real(), so3_core_forward_via_ssht(), so3_core_forward_via_ssht_real(), so3_core_inverse_direct(), so3_core_inverse_direct_real(), so3_core_inverse_via_ssht(), so3_core_inverse_via_ssht_real(), so3_sampling_a2alpha(), so3_sampling_b2beta(), so3_sampling_elmn2ind(), so3_sampling_f_size(), so3_sampling_flmn_size(), so3_sampling_ind2elmn(), so3_sampling_n(), so3_sampling_nalpha(), so3_sampling_nbeta(), so3_test_gen_flmn_complex(), and so3_test_gen_flmn_real().

int so3_parameters_t::L0

Lower harmonic band-limit. flmn with l < L0 will be zero.

Definition at line 137 of file so3_types.h.

Referenced by main(), so3_core_forward_direct(), so3_core_forward_direct_real(), so3_core_forward_via_ssht(), so3_core_forward_via_ssht_real(), so3_core_inverse_direct(), so3_core_inverse_direct_real(), so3_core_inverse_via_ssht(), so3_core_inverse_via_ssht_real(), so3_test_gen_flmn_complex(), and so3_test_gen_flmn_real().

int so3_parameters_t::N

Upper orientational band-limit. Only flmn with n < N will be stored.

Definition at line 151 of file so3_types.h.

Referenced by main(), so3_core_forward_direct(), so3_core_forward_direct_real(), so3_core_forward_via_ssht(), so3_core_forward_via_ssht_real(), so3_core_inverse_direct(), so3_core_inverse_direct_real(), so3_core_inverse_via_ssht(), so3_core_inverse_via_ssht_real(), so3_sampling_elmn2ind(), so3_sampling_f_size(), so3_sampling_flmn_size(), so3_sampling_g2gamma(), so3_sampling_ind2elmn(), so3_sampling_n(), so3_sampling_ngamma(), so3_test_gen_flmn_complex(), and so3_test_gen_flmn_real().

so3_n_mode_t so3_parameters_t::n_mode

Indicates if entire blocks of flm for certain values of n are zero.

Definition at line 177 of file so3_types.h.

Referenced by main(), so3_core_forward_direct(), so3_core_forward_direct_real(), so3_core_forward_via_ssht(), so3_core_forward_via_ssht_real(), so3_core_inverse_direct(), so3_core_inverse_direct_real(), so3_core_inverse_via_ssht(), so3_core_inverse_via_ssht_real(), so3_test_gen_flmn_complex(), and so3_test_gen_flmn_real().

so3_n_order_t so3_parameters_t::n_order

Indicates the order of n-values by which individual flm-blocks are stored.

Definition at line 164 of file so3_types.h.

Referenced by main(), so3_sampling_elmn2ind(), so3_sampling_elmn2ind_real(), so3_sampling_ind2elmn(), and so3_sampling_ind2elmn_real().

int so3_parameters_t::reality

A non-zero value indicates that the signal f is real. Not all functions respect this value - instead there may be separate complex and real functions. See the documentation of each function for details.

Definition at line 131 of file so3_types.h.

Referenced by main(), and so3_sampling_flmn_size().

so3_sampling_t so3_parameters_t::sampling_scheme

Sampling scheme to use for samples of the signal f.

Definition at line 157 of file so3_types.h.

Referenced by main(), so3_core_forward_direct(), so3_core_forward_direct_real(), so3_core_forward_via_ssht(), so3_core_forward_via_ssht_real(), so3_core_inverse_direct(), so3_core_inverse_direct_real(), so3_core_inverse_via_ssht(), so3_core_inverse_via_ssht_real(), so3_sampling_a2alpha(), so3_sampling_b2beta(), so3_sampling_n(), so3_sampling_nalpha(), so3_sampling_nbeta(), and so3_sampling_weight().

int so3_parameters_t::steerable

A non-zero value indicates that the signal is steerable.

Definition at line 188 of file so3_types.h.

Referenced by so3_core_forward_direct(), so3_core_forward_direct_real(), so3_core_forward_via_ssht(), so3_core_forward_via_ssht_real(), so3_core_inverse_direct(), so3_core_inverse_direct_real(), so3_core_inverse_via_ssht(), so3_core_inverse_via_ssht_real(), so3_sampling_g2gamma(), and so3_sampling_ngamma().

so3_storage_t so3_parameters_t::storage

Type of storage (padded or compact).

Definition at line 170 of file so3_types.h.

Referenced by main(), so3_core_forward_direct(), so3_core_forward_direct_real(), so3_core_forward_via_ssht(), so3_core_forward_via_ssht_real(), so3_core_inverse_direct(), so3_core_inverse_direct_real(), so3_core_inverse_via_ssht(), so3_core_inverse_via_ssht_real(), so3_sampling_elmn2ind(), so3_sampling_elmn2ind_real(), so3_sampling_flmn_size(), so3_sampling_ind2elmn(), and so3_sampling_ind2elmn_real().

int so3_parameters_t::verbosity

Detail level for diagnostic console output in range [0,5].

Definition at line 123 of file so3_types.h.

Referenced by main(), so3_core_forward_direct(), so3_core_forward_direct_real(), so3_core_forward_via_ssht(), so3_core_forward_via_ssht_real(), so3_core_inverse_direct(), so3_core_inverse_direct_real(), so3_core_inverse_via_ssht(), and so3_core_inverse_via_ssht_real().

The documentation for this struct was generated from the following file:

- src/c/so3_types.h